@@ -237,10 +237,12 @@ def extract_by_var(vars, state_codes,
             if not os.path.exists(export_tmp_fp):
                 result_df.to_parquet(export_tmp_fp, compression='gzip')
             else:
-                cols_to_use = result_df.columns.difference(tmp_df.columns)
-                print(cols_to_use)
-                tmp_df = pd.merge(tmp_df, results_df[cols_to_use], left_index=True, right_index=True, how='left')
-                # tmp_df = result_df.join(tmp_df, how='left')
+                result_df.drop(['county','state'])
+                tmp_df = result_df.join(tmp_df, how='left', lsuffix='_delete')
+                if 'county_delete' in tmp_df:
+                    tmp_df.drop(['county_delete'], inplace=True)
+                if 'state_delete' in tmp_df:
+                    tmp_df.drop(['state_delete'], inplace=True)    
                 print(tmp_df)
                 tmp_df.to_parquet(export_tmp_fp, compression='gzip')
 
